@@ -1,11 +1,11 @@
 package Anki::Import ;
-$Anki::Import::VERSION = '0.015';
+$Anki::Import::VERSION = '0.016';
 use strict;
 use warnings;
 use Cwd;
 use Path::Tiny;
 use Getopt::Args;
-use Log::Log4perl::Shortcuts qw(:all);
+use Log::Log4perl::Shortcuts 0.011 qw(:all);
 use Exporter qw(import);
 our @EXPORT = qw(anki_import);
 
@@ -332,7 +332,7 @@ Anki::Import - Anki note generation made easy.
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 OVERVIEW
 
